@@ -40,11 +40,11 @@ impl Model for StringModel {
 }
 
 #[test]
-fn round_trip_u32() {
+fn round_trip() {
     let mut file = File::open("./resources/sherlock.txt").unwrap();
     let mut string = String::new();
     file.read_to_string(&mut string).unwrap();
     let input = string.chars().collect();
 
-    common::round_trip(input, StringModel);
+    common::round_trip(StringModel, input);
 }
